==> mad-0.13.0b.tar.gz: mad-0.13.0b/winamp/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by resource.rc
//
#define IDD_CONFIG                      101
#define IDD_PROPPAGE_MPEG               102
#define IDD_PROPPAGE_ID3V1              109
#define IDD_PROPPAGE_ID3V2              110
#define IDD_PROPPAGE_STATS              111
#define IDC_RES_8BITS                   1000
#define IDC_RES_16BITS                  1001
#define IDC_RES_24BITS                  1002
#define IDC_RES_32BITS                  1003
#define IDC_ID3V1_TITLE                 1027
#define IDC_ID3V1_GENRE                 1029
#define IDC_ID3V1_ALBUM                 1031
#define IDC_ID3V1_ARTIST                1032
#define IDC_ID3V1_COMMENT               1033
#define IDC_ID3V1_YEAR                  1036
#define IDC_ID3V1_TRACK                 1038
#define IDC_MISC_FASTTIMECALC           1039
#define IDC_MISC_AVGBITRATE             1040
#define IDC_MPEG_CRC                    1048
#define IDC_MPEG_SINGLECH               1050
#define IDC_MPEG_DUALCH                 1051
#define IDC_MPEG_JOINTST                1052
#define IDC_MPEG_STEREO                 1053
#define IDC_MPEG_COPYRIGHT              1054
#define IDC_MPEG_ORIGINAL               1055
#define IDC_MPEG_TYPE                   1057
#define IDC_MPEG_SIZE                   1059
#define IDC_MPEG_LENGTH                 1060
#define IDC_MPEG_LAYER                  1061
#define IDC_MPEG_BITRATE                1062
#define IDC_MPEG_SAMPLERATE             1063
#define IDC_MPEG_EMPHASIS               1064
#define IDC_MPEG_BITRATELABEL           1065
#define IDC_TITLE_FORMAT                1069
#define IDC_CONF_ENABLED                1075
#define IDC_PRIO_SLIDER                 1076
#define IDC_MPEG_LOCATION               1077
#define IDC_STATS_CLIPPING              1078
#define IDC_STATS_CLIPPED               1079
#define IDC_STATS_DECODED               1080
#define IDC_STATS_CRCERR                1081
#define IDC_STATS_OTHERR                1082
#define IDC_STATS_SYNCERR               1084
#define IDC_STATS_DECIBELS              1085
#define IDC_STATS_ATTENUATE             1086
#define IDC_STATS_RESET                 1087
#define IDC_STATS_ATTENUATION           1088
#define IDC_CHAN_STEREO                 1091
#define IDC_CHAN_MONO                   1092
#define IDC_CHAN_LEFT                   1093
#define IDC_CHAN_RIGHT                  1094
#define IDC_CHAN_REVERSE                1095
#define IDC_OUT_EDIT                    1097
#define IDC_OUT_SPIN                    1098
#define IDC_OUT_AUTOATTENUATION         1099
#define IDC_OUT_DB                      1100
#define IDC_OUT_MAX                     1101
#define IDC_STATS_JSPIE                 1102
#define IDC_STATS_LEGENDMS              1103
#define IDC_STATS_LEGENDI               1104
#define IDC_OUT_SENSITIVITY             1104
#define IDC_OUT_LABEL1                  1105
#define IDC_OUT_LABEL2                  1106
#define IDC_OUT_LABEL3                  1107
#define IDC_MISC_HIRESDSP               1108

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        116
#define _APS_NEXT_COMMAND_VALUE         40004
#define _APS_NEXT_CONTROL_VALUE         1109
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> mad-0.14.2b.tar.gz: mad-0.14.2b/winamp/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by resource.rc
//
#define IDD_CONFIG                      101
#define IDD_PROPPAGE_MPEG               102
#define IDD_PROPPAGE_ID3V1              109
#define IDD_PROPPAGE_ID3V2              110
#define IDD_PROPPAGE_STATS              111
#define IDC_RES_8BITS                   1000
#define IDC_RES_16BITS                  1001
#define IDC_RES_24BITS                  1002
#define IDC_RES_32BITS                  1003
#define IDC_ID3V1_TITLE                 1027
#define IDC_ID3V1_GENRE                 1029
#define IDC_ID3V1_ALBUM                 1031
#define IDC_ID3V1_ARTIST                1032
#define IDC_ID3V1_COMMENT               1033
#define IDC_ID3V1_YEAR                  1036
#define IDC_ID3V1_TRACK                 1038
#define IDC_MISC_FASTTIMECALC           1039
#define IDC_MISC_AVGBITRATE             1040
#define IDC_MPEG_CRC                    1048
#define IDC_MPEG_COPYRIGHT              1054
#define IDC_MPEG_ORIGINAL               1055
#define IDC_MPEG_TYPE                   1057
#define IDC_MPEG_SIZE                   1059
#define IDC_MPEG_LENGTH                 1060
#define IDC_MPEG_LAYER                  1061
#define IDC_MPEG_SAMPLERATE             1062
#define IDC_MPEG_SAMPLERATE2            1062
#define IDC_MPEG_MODE                   1063
#define IDC_MPEG_EMPHASIS               1064
#define IDC_MPEG_BITRATE                1065
#define IDC_TITLE_FORMAT                1069
#define IDC_CONF_ENABLED                1075
#define IDC_PRIO_SLIDER                 1076
#define IDC_MPEG_LOCATION               1077
#define IDC_STATS_CLIPPING              1078
#define IDC_STATS_CLIPPED               1079
#define IDC_STATS_DECODED               1080
#define IDC_STATS_CRCERR                1081
#define IDC_STATS_OTHERR                1082
#define IDC_STATS_SYNCERR               1084
#define IDC_STATS_ATTENUATE             1086
#define IDC_STATS_RESET                 1087
#define IDC_STATS_ATTENUATION           1088
#define IDC_CHAN_STEREO                 1091
#define IDC_CHAN_MONO                   1092
#define IDC_CHAN_LEFT                   1093
#define IDC_CHAN_RIGHT                  1094
#define IDC_CHAN_REVERSE                1095
#define IDC_OUT_AUTOATTENUATION         1099
#define IDC_STATS_JSPIE                 1102
#define IDC_STATS_LEGENDMS              1103
#define IDC_STATS_LEGENDI               1104
#define IDC_OUT_SENSITIVITY             1104
#define IDC_OUT_LABEL1                  1105
#define IDC_OUT_LABEL2                  1106
#define IDC_OUT_LABEL3                  1107
#define IDC_MISC_HIRESDSP               1108
#define IDC_CONF_STREAMING              1109
#define IDC_ID3V2_FRAMES                1110
#define IDC_ID3V2_SYNC                  1111
#define IDC_ID3V2_ADD                   1112
#define IDC_ID3V2_REMOVE                1113

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        116
#define _APS_NEXT_COMMAND_VALUE         40004
#define _APS_NEXT_CONTROL_VALUE         1115
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
